@@ -119,9 +119,33 @@ def atrpips(data, length):
 
     return atr_pips
 
-def atrlimit(data, length, limit, coef):
+def atrlimit(data, length, ss_length):
     """Average True Range implementation with a limit for using as a volatility indicator
 
+    Arguments:
+        data {list} -- List of ohlc data [open, high, low, close]
+        length {int} -- Lookback period for atr indicator
+        ss_length{int} -- super smoother length to be used as threashold
+
+    Returns:
+        list -- List of ones and zeros to be used as volatility indicator
+    """
+    atrl = []
+    th = []
+
+    avgtr = atr(data, length)
+    s_avgtr = super_smoother(avgtr, ss_length)
+
+    for t, _ in enumerate(avgtr):
+        if avgtr[t] >= s_avgtr[t]:
+            atrl.append(1)
+        else:
+            atrl.append(0)
+    return atrl
+
+def smoothed_atrlimit(data, length, limit, coef):
+    """Smoothed Average True Range implementation with a limit for using as a volatility indicator
+
     Arguments:
         data {list} -- List of ohlc data [open, high, low, close]
         length {int} -- Lookback period for atr indicator
@@ -134,7 +158,7 @@ def atrlimit(data, length, limit, coef):
     atrl = []
     th = []
 
-    avgtr = atr(data, length)
+    avgtr = smoothed_atr(data, length)
     for i, _ in enumerate(data):
         if  i < limit:
             th.append(0)
@@ -874,3 +898,30 @@ def noise_elemination_tech(data, length):
 
         net.append(n / denom[i])
     return net
+
+def volume_heat(data, ma_length):
+    vh = []
+
+    for i, _ in enumerate(data):
+        if i < ma_length:
+            vh.append(0)
+        else:
+            mean = statistics.mean(data[i - ma_length:i + 1])
+            std = statistics.stdev(data[i - ma_length:i + 1])
+
+            if (data[i] - mean) / std > 1:
+                vh.append(1)
+            else:
+                vh.append(0)
+    return vh
+
+def double_super_smoother(data, ssf_length1, ssf_length2):
+    ssf1 = super_smoother(data, ssf_length1)
+    ssf2 = super_smoother(data, ssf_length2)
+
+    dssf = []
+
+    for i, _ in enumerate(ssf1):
+        dssf.append(ssf1[i] - ssf2[i])
+
+    return dssf
